#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-98EBphoaeBDJnxScrHiyKi
key:                  test-framework-smallcheck-0.2-98EBphoaeBDJnxScrHiyKi
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  5b5aef8ea9312e104668c876ae1dc80b
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:
    /usr/lib/ghc-8.10.5/site-local/test-framework-smallcheck-0.2

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/test-framework-smallcheck-0.2

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/test-framework-smallcheck-0.2

hs-libraries:         HStest-framework-smallcheck-0.2-98EBphoaeBDJnxScrHiyKi
depends:
    base-4.14.2.0 smallcheck-1.2.1-1S0MjsMyJSO9u8m8c1EIIx
    test-framework-0.8.2.0-5eYG3NRKVE7L7pW0FKysaQ transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

